#devtools::install_github("anthonydn/treateffect@2baef88")
# tidyverse 1.2.1 --
# ggplot2 2.2.1      purrr   0.2.4
# tibble  1.4.2      dplyr   0.7.4
# tidyr   0.8.0      stringr 1.3.0
# readr   1.1.1      forcats 0.3.0
library(treateffect)
smc <- c("black", "gray", "red", "#4686C6")
smcd <- c("gray", "red", "#4686C6")
theme_te()

smn_scale <- function() scale_x_continuous(
  breaks = c(147, 161, 171, 181, 193, 208, 226),
  limits = c(142, 228),
  labels = c("May 26", "Jun 9", "Jun 19", "Jun 29", "Jul 11", "Jul 26",  "Aug 13"))
  
#data reporting functions
summex <- function(x, ..., cen = "mean", pm = "se", digits = 2, units) {
  ex <- x$summaries %>%
    filter_(.dots = lazyeval::lazy_dots(...))
  paste0(round(ex[cen], digits = digits),
    " \u00b1 ", round(ex[pm], digits = digits), units)}

compex_fracdiff <- function(x, ..., cen = "effect_size", lo = "lwr",
  hi = "upr", digits = 2, units = "", factor = 1) {
  ex <- x$comparisons %>%
    filter_(.dots = lazyeval::lazy_dots(...))
  paste0(round(ex[cen] * factor, digits = digits),
    units, " [", round(ex[lo] * factor, digits = digits),", ",
    round(ex[hi] * factor, digits = digits), "]")}

compex_bootdiff <- function(x, ..., cen = "effect_size", lo = "lwr",
    hi = "upr", digits = 2, units = "", factor = 1) {
  ex <- x$comparisons %>%
    filter_(.dots = lazyeval::lazy_dots(...))
  paste0(round(ex[cen] * factor, digits = digits),
    units, " [", round(ex[lo] * factor, digits = digits),", ",
    round(ex[hi] * factor, digits = digits), "]")}

##PHYSICAL CONDITIONS
cond_plot <- list(geom_vline(xintercept = 
    c(119, 124, 133, 134, 137, 138, 141, 146, 152, 161)),
  scale_x_continuous(breaks = c(118, 125, 135, 141, 148, 152, 161),
    lim = c(108, 170),
  labels = c("Apr 28","May 5","May 15","May 21","May 28", "Jun 1", "Jun 10")),
  scale_color_manual(values = c("black", "forestgreen")),
  facet_grid(year ~ .))

#soil temp
ib <- read.csv("ibuttons.csv")
ib$doy[ib$hour == 23] <- ib$doy[ib$hour == 23]+1
ib <- mutate(ib, hour = plyr::mapvalues(hour, c(23,1,3,5,7,9,11,13,15,17,19,21),
    c(0,0,4,4,8,8,12,12,16,16,20,20)), time = doy + (hour/24)) %>%
  filter(temp < 12, treatment %in% c("C.N", "A.N"), 
    tussock == "I", year != 2009) %>%
  group_by(year, time, treatment) %>%
  summarise(temp = mean(temp))
ggplot(ib, aes(time, temp, col = treatment)) + geom_line() + cond_plot

#snow depth
snowdepth <- read.csv("snowdepth.csv") %>%
  group_by(year, doy, treatment) %>% 
  summarise(depth = mean(depth))
ggplot(snowdepth, aes(doy, depth, col = treatment)) + geom_line(lwd = 2) + cond_plot

#air temp
read.csv("airtemp.csv") %>% 
  group_by(year, doy, treatment) %>% summarise(temp = mean(air_temp_mean)) %>% 
  filter(treatment == "C.N" | treatment == "A.N") %>% 
ggplot(aes(doy, temp, col = treatment)) + geom_line(lwd = 2) + cond_plot

#thaw depth
thawdepth <- read.csv("thaw_depth.csv") %>%
  group_by(year, doy, snow, otc) %>% 
  mutate(treatment = ordered(interaction(snow,otc), 
    c("C.N", "A.N", "C.O", "A.O")))
thawdepth %>% 
  filter(otc != "Extra") %>% 
  treateffect(thaw.depth ~ treatment | date, block = "block",
    average_subsamples = TRUE, comp_groups = mcc) %>%
  plot(treatcol = smc)


##PHENOLOGY
pheno <- read_csv("phenology.csv") %>%
  filter(species == "BETNAN" | species == "CARBIG" | 
    species == "ERIVAG" | species == "SALPUL") %>%
  mutate(treatment = ordered(treatment, c("C.N", "A.N", "C.O", "A.O")),
    species = ordered(species, c("ERIVAG", "CARBIG", "BETNAN", "SALPUL")))

pheno.te <- treateffect(pheno, FLE ~ treatment|year+species, 
  comp_function = bootdiff_bca, comp_groups = mcc)
plot(pheno.te, treatcol = smc, points = FALSE)


##NDVI
ndvi <- read_csv("ndvi.csv")

ndvi_f4 <- ndvi %>% 
  filter(sketchy == "no") %>% 
  group_by(year, treatment, block) %>% 
  top_n(4, -doy) %>% 
  summarise(first4 = mean(NDVI))

ndvi <- ndvi %>% 
  filter(sketchy == "no") %>% 
  left_join(ndvi_f4) %>% 
  mutate(treatment = ordered(treatment, 
    c("C.N", "A.N", "C.O", "A.O", "C.S"))) %>% 
  group_by(year, treatment, block) %>% 
  mutate(NDVI_scaled = as.numeric(scale(NDVI - first4, center = FALSE)))

mb <- coef(lm(ndvi$NDVI ~ ndvi$NDVI_scaled))
ndvi$NDVI_scaled <- ndvi$NDVI_scaled * mb[2] + mb[1]
ndvi$treatment[ndvi$treatment == "C.S"] <- "C.N"

ndvi.te <- ndvi %>% treateffect(NDVI_scaled ~ treatment | year, 
  time = "doy")
plot(ndvi.te, treatcol = c(smc), points = F, panel_formula = year + response ~ .,
  dodge = 1, scales = "fixed") + smn_scale()

ndvi.june <- ndvi %>% 
  filter(doy > 151, doy < 182) %>% 
  treateffect(NDVI_scaled ~ treatment | year, average_subsamples = TRUE, 
    block = "block", comp_function = bootdiff_bca)

ndvi.july <- ndvi %>% 
  filter(doy > 181, doy < 213) %>% 
  treateffect(NDVI_scaled ~ treatment | year, average_subsamples = TRUE, 
    block = "block", comp_function = bootdiff_bca)

plot(ndvi.june, treatcol = smc, points = TRUE)

compex_bootdiff(ndvi.june, comparison == "A.O - C.N", year == 2010, digits = 3)
compex_bootdiff(ndvi.june, comparison == "A.O - C.N", year == 2011, digits = 3)
compex_bootdiff(ndvi.june, comparison == "A.O - C.N", year == 2012, digits = 3)
compex_bootdiff(ndvi.june, comparison == "A.N - C.N", year == 2012, digits = 3)
compex_bootdiff(ndvi.june, comparison == "C.O - C.N", year == 2012, digits = 3)
compex_bootdiff(ndvi.june, comparison == "A.O - C.N", year == 2012, digits = 3)
compex_bootdiff(ndvi.july, comparison == "A.N - C.N", year == 2012, digits = 3)
compex_bootdiff(ndvi.july, comparison == "C.O - C.N", year == 2012, digits = 3)
compex_bootdiff(ndvi.july, comparison == "A.O - C.N", year == 2012, digits = 3)


##ROOT PRODUCTION

roots <- read.csv("roots.csv")
tubestats <- read.csv("tubestats.csv")

rall <- roots %>%
  separate(Treatment, c("snow", "otc"), 1, remove = FALSE) %>% 
  mutate(Treatment = ordered(Treatment, c("CN", "AN", "CO", "AO")),
    snow = ordered(snow, c("C", "A")),
    otc = ordered(otc, c("N", "O"))) %>% 
  group_by(Type, Year, doy, Treatment, snow, otc, Tube) %>%
  summarise(root_area = sum(PA)) %>% 
  left_join(tubestats %>% select(Tube, length = length.of.tube,
    depth = tubedepth)) %>% 
  mutate(root_g = ifelse(Type == "ERVA", root_area/100 * 0.01009, 
    root_area/100 * 0.01648), #100 mm2 cm^-2^
    root_g_m2 = root_g * (depth / length) * (1e4 / (1.3 * 0.3)))

rall.te <- filter(rall, Year != 2010) %>% 
  treateffect(root_g_m2 ~ Treatment | Year + Type, 
    times = "doy", comp_function = bootRR_bca)

rall_snow.te <- filter(rall, Year != 2010) %>%
  treateffect(root_g_m2 ~ snow | Year + Type,
  times = "doy", comp_function = bootRR_bca)

plot(rall.te, points = T, dodge = 4, treatcol = smc, 
  panel_formula = Year ~ Type) + smn_scale()

summex(rall.te, Year == 2011, Type == "ERVA", doy == 225,
  x == "CN", units = " g m^-2^", digits = 0)
summex(rall.te, Year == 2012, Type == "ERVA", doy == 217,
  x == "CN", units = " g m^-2^", digits = 0)
filter(rall, Year == 2011, Treatment == "CN", doy == 225, 
  Type == "ERVA")$root_g_m2 %>% max %>% round(., 0)
summex(rall.te, Year == 2011, Type == "NonERVA", doy == 225,
  x == "CN", units = " g m-2", digits = 0)
summex(rall.te, Year == 2012, Type == "NonERVA", doy == 217,
  x == "CN", units = " g m-2", digits = 0)
filter(rall, Year == 2011, Treatment == "CN", doy == 225,
  Type == "NonERVA")$root_g_m2 %>% max %>% round(., 0)
compex_fracdiff(rall.te, Year == 2011, Type == "NonERVA",
  comparison == "AN - CN", doy == 225)
compex_fracdiff(rall.te, Year == 2011, Type == "NonERVA",
  comparison == "AO - CN", doy == 225)
compex_fracdiff(rall_snow.te, Year == 2011, Type == "NonERVA",
  comparison == "A - C", doy == 225)
compex_fracdiff(rall_snow.te, Year == 2011, Type == "ERVA",
  comparison == "A - C", doy == 225)


##MICROBIAL BIOMASS

cores <- read.csv("cores.csv") %>% 
  filter(year == 2012) %>% 
  mutate(treatment = ordered(treatment, 
    levels = c("C.N", "A.N", "C.O", "A.O")))

mb.te <- cores %>%
  filter(!is.na(cores$mbc)) %>% 
treateffect(mbc + mbn ~ treatment | tussock, 
  times = "doy", comp_function = bootRR_bca, comp_groups = mcc)
plot(mb.te, dodge = 4, treatcol = smc) + smn_scale()

compex_fracdiff(mb.te, response == "mbc", tussock == "I",
  comparison == "C.O - C.N", doy == 146, digits = 1)
compex_fracdiff(mb.te, response == "mbc", tussock == "T",
  comparison == "C.O - C.N", doy == 148, digits = 1)
compex_fracdiff(mb.te, response == "mbn", tussock == "I",
  comparison == "C.O - C.N", doy == 146, digits = 1)
compex_fracdiff(mb.te, response == "mbn", tussock == "T",
  comparison == "C.O - C.N", doy == 148, digits = 1)
compex_fracdiff(mb.te, response == "mbc", tussock == "I",
  comparison == "A.N - C.N", doy == 146, digits = 1)


##SOIL MOISTURE

read.csv("cores.csv") %>% 
  mutate(treatment = ordered(treatment, levels = c("C.N", "A.N", "C.O", "A.O"))) %>% 
  treateffect(moisture ~ treatment | tussock + year, times = "doy") %>% 
  plot(dodge = 4, treatcol = smc) + smn_scale()


##MICROARTHROPODS

bugs <- read.csv("bugs.csv") %>% 
  mutate(treatment = ordered(treatment, levels = c("C.N", "A.N")),
    bugs.v = bugs / volume,
    fmites.v = fmites / volume,
    pmites.v = pmites / volume,
    collembola.v = collembola / volume)
bugs.te <- treateffect(bugs, bugs.v + fmites.v + pmites.v + collembola.v ~ treatment, 
  times = "doy", comp_function = bootRR_bca)
plot(bugs.te, points = T, dodge = 2, treatcol = smc) + smn_scale()

compex_fracdiff(bugs.te, response == "fmites.v", doy == 159)
compex_fracdiff(bugs.te, response == "bugs.v", doy == 159)


##SOIL PORE WATER NUTRIENTS

ml <- read.csv("soilporewater.csv") %>% 
  mutate(treatment = ordered(treatment, 
    levels = c("C.N", "A.N", "C.O", "A.O"))) %>% 
  filter(suspicious != "yes")

ml.te <- treateffect(ml, labile ~ treatment | tussock + year, times = "doy", 
  block = "block")

ml.season <- treateffect(ml, labile ~ treatment | year + tussock,
  average_subsamples = TRUE, block = "block", comp_function = bootRR_bca)

plot(ml.te, dodge = 2, treatcol = smc) + smn_scale()

compex_fracdiff(ml.season, year == 2011, 
  comparison == "A.N - C.N", tussock == "T")
compex_fracdiff(ml.season, year == 2011,
  comparison == "A.N - C.N", tussock == "I")

ml.te <- filter(ml, year == 2011, tussock == "T", 
  treatment %in% c("C.N", "A.N")) %>% 
  treateffect(labile ~ treatment | tussock + year, times = "doy", 
  block = "block", comp_function = bootdiff_bca, comp_groups = mcc)
plotdiff(ml.te, treatcol = smcd)

plot(ml.season, treatcol = smc, points = TRUE)


##SOIL CORE NUTRIENTS

n.te <- treateffect(cores, labile + no3 + nh4 + tfpa ~ treatment | tussock, 
  times = "doy", comp_function = bootRR_bca)
plot(n.te, dodge = 4, treatcol = smc) + smn_scale()

npool.te <- cores %>% 
  separate(treatment, c("snow", "otc")) %>% 
  mutate(snow = ordered(snow)) %>% 
  treateffect(labile + no3 + nh4 + tfpa ~ snow | tussock, 
    times = "doy", comp_function = bootRR_bca)

library(hotspots)
summary(hotspots(cores$labile))

compex_fracdiff(npool.te, response == "labile", doy == 148, digits = 2)


##EXOENZYMES

enzymes.te <- cores %>% 
  filter(NAG < 4000) %>% #removed for plotting purposes
treateffect(BG + NAG + LAP + PHENOX ~ treatment | tussock, 
  times = "doy", comp_function = bootRR_bca)
plot(enzymes.te, dodge = 4, treatcol = smc) + smn_scale()

compex_fracdiff(enzymes.te, response == "LAP", doy == 146,
  tussock == "I", comparison == "C.O - C.N", digits = 1)
compex_fracdiff(enzymes.te, response == "LAP", doy == 146,
  tussock == "I", comparison == "A.O - C.N", digits = 1)
compex_fracdiff(enzymes.te, response == "NAG", doy == 146,
  tussock == "I", comparison == "C.O - C.N", digits = 1)
compex_fracdiff(enzymes.te, response == "NAG", doy == 146,
  tussock == "I", comparison == "A.O - C.N", digits = 1)
compex_fracdiff(enzymes.te, response == "LAP", doy == 146,
  tussock == "I", comparison == "A.N - C.N", digits = 1)
compex_fracdiff(enzymes.te, response == "NAG", doy == 146,
  tussock == "I", comparison == "A.N - C.N", digits = 1)


##INTERANNUAL VARIATION TABLE

ib <- read.csv("ibuttons.csv")
ib$doy[ib$hour == 23] <- ib$doy[ib$hour == 23]+1
ib <- mutate(ib, hour = plyr::mapvalues(hour, c(23,1,3,5,7,9,11,13,15,17,19,21),
    c(0,0,4,4,8,8,12,12,16,16,20,20)), time = doy + (hour/24)) %>%
  #only 2 blocks w data for all three years
  filter(temp < 12, treatment == "C.N", tussock == "T", block %in% c(1,4)) %>% 
  group_by(year, time, treatment) %>%
  summarise(temp = mean(temp))

ib %>% 
  filter(time > 230, time < 260) %>% 
  ungroup %>% 
  group_by(year) %>%
  summarise(n = n(), temp = mean(temp, na.rm = TRUE))

ib %>% 
  filter(time >= 260) %>% 
  ungroup %>% 
  group_by(year) %>%
  summarise(n = n(), temp = mean(temp, na.rm = TRUE))

ib %>% 
  filter(time < 121) %>% 
  ungroup %>% 
  group_by(year) %>%
  summarise(n = n(), temp = mean(temp, na.rm = TRUE))

read.csv("snowdepth.csv") %>% 
  filter(treatment == "C.N") %>% 
  group_by(year, doy, block) %>% 
  summarise(depth = mean(depth)) %>% 
  ungroup() %>% 
  group_by(year, doy) %>% 
  summarise(n = n(), depth_mean = mean(depth), depth_se = se(depth)) %>% 
  ungroup %>% 
  group_by(year) %>% 
  filter(depth_mean == max(depth_mean))

interannual_tussock <- read.csv("cores.csv") %>% 
  filter(tussock == "T", treatment == "C.N", doy %in% c(147, 152, 148)) %>% 
  select(year, block, tussock, labile, mbn, LAP, NAG) %>% 
  treateffect(labile + mbn + LAP + NAG ~ year,
    comp_function = bootRR_bca)

interannual_intertussock <- read.csv("cores.csv") %>% 
  filter(tussock == "I", treatment == "C.N", doy %in% c(161, 152, 146)) %>% 
  select(year, block, tussock, labile, mbn, LAP, NAG) %>% 
  treateffect(labile + mbn + LAP + NAG ~ year, 
    comp_function = bootRR_bca)

compex_fracdiff(interannual_tussock, response == "labile",
  comparison == "2011 - 2010")
compex_fracdiff(interannual_tussock, response == "mbn",
  comparison == "2011 - 2010")
compex_fracdiff(interannual_tussock, response == "LAP",
  comparison == "2011 - 2010")
compex_fracdiff(interannual_tussock, response == "NAG",
  comparison == "2011 - 2010")
compex_fracdiff(interannual_tussock, response == "labile",
  comparison == "2012 - 2011")


###APPENDIX

#RHIZOTRON DETAIL
rr <- roots %>%
   filter(
     Date == "2010-08-11"|
     Date == "2011-08-13"|
     Date == "2012-08-04") %>%
   group_by(Type, Year, Date, Treatment, Tube, Depth, Block) %>%
   summarise(root_area = sum(PA))
 rr <- merge(rr, tubestats[1:40, c("Tube", "tubedepth")])
 rr$Treatment <- ordered(rr$Treatment,c("CN", "AN", "CO", "AO"))
 
 ggplot(subset(rr, Type == "ERVA"),
     aes(-Depth, root_area, col = Treatment, fill = Treatment)) + 
   geom_bar(stat = "identity", width=0.5, linetype = "blank") +
   geom_vline(aes(xintercept = -tubedepth - 0.5)) +
   coord_flip() +
   scale_color_manual(values = smc) +
   scale_fill_manual(values = smc) +
   facet_grid(Year ~ Treatment + Block + Tube)
 
 ggplot(subset(rr, Type == "NonERVA"),
     aes(-Depth, root_area, col = Treatment, fill = Treatment)) + 
   geom_bar(stat = "identity", width=0.5, linetype = "blank") +
   geom_vline(aes(xintercept = -tubedepth - 0.5)) +
   coord_flip() +
   scale_color_manual(values = smc) +
   scale_fill_manual(values = smc) +
   facet_grid(Year ~ Treatment + Block + Tube)


#NDVI
read_csv("ndvi.csv") %>% 
  filter(sketchy == "no") %>% 
  ggplot(aes(doy, NDVI, col = interaction(treatment, block))) +
  geom_line(lwd = 1) +
  facet_grid(year ~ .) +
  scale_color_manual(values = rep(c("gray", "navyblue", "black",
    "red", "black"), 5)) + 
  scale_x_continuous(breaks = c(147, 161, 171, 181, 193, 208, 226),
    limits = c(135, 245),
    labels = c("May 26", "Jun 9", "Jun 19", "Jun 29", "Jul 11", 
       "Jul 26",  "Aug 13"))
